==> xl-react-components-0.18.103.tgz: package/app/xl-react-widget/xl-react-widget-category/xl-react-widget-category.js <==
import R from 'ramda';
import React, {PureComponent} from 'react';
import classNames from 'classnames';
import PropTypes from 'prop-types';

import './xl-react-widget-category.less';

export class XlReactWidgetCategory extends PureComponent {
    static propTypes = {
        categoryClassName: PropTypes.string,
        categoryName: PropTypes.node.isRequired,
        children: PropTypes.oneOfType([PropTypes.object, PropTypes.array]),
        className: PropTypes.string,
        collapsable: PropTypes.bool.isRequired,
        open: PropTypes.bool.isRequired,
        titleHidden: PropTypes.bool,
        toggleOpen: PropTypes.func.isRequired
    };

    static defaultProps = {collapsable: true, titleHidden: false};

    handleOnClick = () => {
        if (this.props.collapsable) {
            this.props.toggleOpen();
        }
    };

    render() {
        const {
            categoryClassName,
            categoryName,
            children,
            className,
            collapsable,
            open,
            titleHidden
        } = this.props;

        const componentClassName = classNames('xl-react-widget-category', {[className]: !R.isNil(className), open});
        const categoryClazzName = classNames('xl-react-category', categoryClassName,
            {collapsable, hidden: titleHidden});

        return <div className={componentClassName}>
            <div className={categoryClazzName} onClick={this.handleOnClick}> {categoryName}</div>
            <div className="xl-react-category-content">
                {children}
            </div>
        </div>;
    }
}

==> xl-react-components-0.21.9.tgz: package/app/xl-react-widget/xl-react-widget-category/xl-react-widget-category.js <==
import R from 'ramda';
import React, {PureComponent} from 'react';
import classNames from 'classnames';
import PropTypes from 'prop-types';

import './xl-react-widget-category.less';

export class XlReactWidgetCategory extends PureComponent {
    static propTypes = {
        categoryClassName: PropTypes.string,
        categoryName: PropTypes.node.isRequired,
        children: PropTypes.oneOfType([PropTypes.object, PropTypes.array]),
        className: PropTypes.string,
        collapsable: PropTypes.bool.isRequired,
        open: PropTypes.bool.isRequired,
        titleHidden: PropTypes.bool,
        toggleOpen: PropTypes.func.isRequired
    };

    static defaultProps = {collapsable: true, titleHidden: false};

    handleOnClick = () => {
        if (this.props.collapsable) {
            this.props.toggleOpen();
        }
    };

    render() {
        const {
            categoryClassName,
            categoryName,
            children,
            className,
            collapsable,
            open,
            titleHidden
        } = this.props;

        const componentClassName = classNames('xl-react-widget-category', {[className]: !R.isNil(className), open});
        const categoryClazzName = classNames('xl-react-category', categoryClassName,
            {collapsable, hidden: titleHidden});

        return <div className={componentClassName}>
            <div className={categoryClazzName} onClick={this.handleOnClick}>
                {collapsable && <i className="xl-icon chevron-right-icon"/>}
                {categoryName}
            </div>
            <div className="xl-react-category-content">
                {children}
            </div>
        </div>;
    }
}
